InputModel class

Constructors

InputModel({String? path = 'lib', String? outputPath = 'assets/language', String? sheetUrl, String? sheetId, String? sheetName, int? column = 1, int? row = 1, bool? all = true, String? keyName = 'key-getx-translator'})
InputModel.fromJson(Map<String, dynamic> json)

Properties

all ↔ bool?
getter/setter pair
column ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyName ↔ String?
getter/setter pair
outputPath ↔ String?
getter/setter pair
path ↔ String?
getter/setter pair
row ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetId ↔ String?
getter/setter pair
sheetName ↔ String?
getter/setter pair
sheetUrl ↔ String?
getter/setter pair

Methods

copyWith({String? path, String? outputPath, String? sheetUrl, String? sheetId, String? sheetName, int? column, int? row, bool? all, String? keyName}) → InputModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited